@@ -1,7 +1,7 @@
 """Representation of evergreen manifest."""
 from __future__ import absolute_import
 
-from typing import Any, Dict, Optional, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Dict, Optional
 
 from evergreen.base import _BaseEvergreenObject, evg_attrib
 
